# Configure Datadog metric keys for use in the application
HTTP_REQUEST = 'microengine.http'
HTTP_RESPONSE_TIMER = 'microengine.request.time'
SCAN_SUCCESS = 'microengine.scan.success'
SCAN_FAIL = 'microengine.scan.fail'
SCAN_EXPIRED = 'microengine.scan.expired'
SCAN_TYPE_VALID = 'microengine.scan.valid-type'
SCAN_TYPE_INVALID = 'microengine.scan.invalid-type'
SCAN_NO_RESULT = 'microengine.scan.no-result'
SCAN_TIME = 'microengine.scan.time'
SCAN_VERDICT = 'microengine.scan.verdict'